@@ -1,9 +1,6 @@
-var PETRA = function(m)
+PETRA.ResearchPlan = function(gameState, type, rush = false)
 {
-
-m.ResearchPlan = function(gameState, type, rush = false)
-{
-	if (!m.QueuePlan.call(this, gameState, type, {}))
+	if (!PETRA.QueuePlan.call(this, gameState, type, {}))
 		return false;
 
 	if (this.template.researchTime === undefined)
@@ -20,9 +17,9 @@ m.ResearchPlan = function(gameState, type, rush = false)
 	return true;
 };
 
-m.ResearchPlan.prototype = Object.create(m.QueuePlan.prototype);
+PETRA.ResearchPlan.prototype = Object.create(PETRA.QueuePlan.prototype);
 
-m.ResearchPlan.prototype.canStart = function(gameState)
+PETRA.ResearchPlan.prototype.canStart = function(gameState)
 {
 	this.researchers = this.getBestResearchers(gameState);
 	if (!this.researchers)
@@ -31,7 +28,7 @@ m.ResearchPlan.prototype.canStart = function(gameState)
 	return true;
 };
 
-m.ResearchPlan.prototype.getBestResearchers = function(gameState, noRequirementCheck = false)
+PETRA.ResearchPlan.prototype.getBestResearchers = function(gameState, noRequirementCheck = false)
 {
 	let allResearchers = gameState.findResearchers(this.type, noRequirementCheck);
 	if (!allResearchers || !allResearchers.hasEntities())
@@ -54,12 +51,12 @@ m.ResearchPlan.prototype.getBestResearchers = function(gameState, noRequirementC
 	return researchers;
 };
 
-m.ResearchPlan.prototype.isInvalid = function(gameState)
+PETRA.ResearchPlan.prototype.isInvalid = function(gameState)
 {
 	return gameState.isResearched(this.type) || gameState.isResearching(this.type);
 };
 
-m.ResearchPlan.prototype.start = function(gameState)
+PETRA.ResearchPlan.prototype.start = function(gameState)
 {
 	// Prefer researcher with shortest queues (no need to serialize this.researchers
 	// as the functions canStart and start are always called on the same turn)
@@ -71,7 +68,7 @@ m.ResearchPlan.prototype.start = function(gameState)
 	this.onStart(gameState);
 };
 
-m.ResearchPlan.prototype.onStart = function(gameState)
+PETRA.ResearchPlan.prototype.onStart = function(gameState)
 {
 	if (this.queueToReset)
 		gameState.ai.queueManager.changePriority(this.queueToReset, gameState.ai.Config.priorities[this.queueToReset]);
@@ -86,7 +83,7 @@ m.ResearchPlan.prototype.onStart = function(gameState)
 	}
 };
 
-m.ResearchPlan.prototype.Serialize = function()
+PETRA.ResearchPlan.prototype.Serialize = function()
 {
 	return {
 		"category": this.category,
@@ -100,7 +97,7 @@ m.ResearchPlan.prototype.Serialize = function()
 	};
 };
 
-m.ResearchPlan.prototype.Deserialize = function(gameState, data)
+PETRA.ResearchPlan.prototype.Deserialize = function(gameState, data)
 {
 	for (let key in data)
 		this[key] = data[key];
@@ -108,6 +105,3 @@ m.ResearchPlan.prototype.Deserialize = function(gameState, data)
 	this.cost = new API3.Resources();
 	this.cost.Deserialize(data.cost);
 };
-
-return m;
-}(PETRA);
