@@ -2,6 +2,7 @@ var g_TooltipTextFormats = {
 	"unit": { "font": "sans-10", "color": "orange" },
 	"header": { "font": "sans-bold-13" },
 	"body": { "font": "sans-13" },
+	"objection": { "font": "sans-bold-13", "color": "red" },
 	"comma": { "font": "sans-12" },
 	"namePrimaryBig": { "font": "sans-bold-16" },
 	"namePrimarySmall": { "font": "sans-bold-12" },
@@ -81,6 +82,11 @@ function bodyFont(text)
 	return setStringTags(text, g_TooltipTextFormats.body);
 }
 
+function objectionFont(text)
+{
+	return setStringTags(text, g_TooltipTextFormats.objection);
+}
+
 function headerFont(text)
 {
 	return setStringTags(text, g_TooltipTextFormats.header);
@@ -956,14 +962,24 @@ function getEntityCostTooltip(template, player, entity, buildingsCountToTrainFul
 	return "";
 }
 
-function getRequiredTechnologyTooltip(technologyEnabled, requiredTechnology, civ)
+function getRequirementsTooltip(enabled, requirements, civ)
 {
-	if (technologyEnabled)
+	if (enabled)
 		return "";
 
-	return sprintf(translate("Requires %(technology)s"), {
-		"technology": getEntityNames(GetTechnologyData(requiredTechnology, civ))
-	});
+	// Simple requirements (one tech) can be translated on the fly.
+	if ("Techs" in requirements && !requirements.Techs._string.includes(" ") &&
+			requirements.Techs._string[0] != "!")
+		return objectionFont(sprintf(translate("Requires %(technology)s"), {
+			"technology": getEntityNames(GetTechnologyData(requirements.Techs._string, civ))
+		}));
+
+	// More complex ones need a tooltip.
+	if ("Tooltip" in requirements)
+		return objectionFont(translate(requirements.Tooltip));
+
+	warn("Complex requirements found, but no tooltip specified. More complex requirements can't be translated on the fly easily.")
+	return "";
 }
 
 /**
@@ -994,10 +1010,8 @@ function getNeededResourcesTooltip(resources)
 			"component": '[font="sans-12"]' + resourceIcon(resource) + '[/font]',
 			"cost": Math.ceil(resources[resource])
 		}));
-	return coloredText(
-		'[font="sans-bold-13"]' + translate("Insufficient resources:") + '[/font]',
-		"red") + " " +
-		formatted.join("  ");
+	return objectionFont(translate("Insufficient resources:")) +
+		" " + formatted.join("  ");
 }
 
 function getSpeedTooltip(template)
@@ -1205,16 +1219,28 @@ function getResourceDropsiteTooltip(template)
 	});
 }
 
-function showTemplateViewerOnRightClickTooltip()
+function getFocusOnLeftClickTooltip()
 {
-	// Translation: Appears in a tooltip to indicate that right-clicking the corresponding GUI element will open the Template Details GUI page.
-	return translate("Right-click to view more information.");
+	// Translation: Appears in a tooltip to indicate that left-clicking the corresponding GUI element will center the view on the selected entity.
+	return translate("Left-click to focus.");
 }
 
-function showTemplateViewerOnClickTooltip()
+function getFollowOnLeftClickTooltip()
+{
+	// Translation: Appears in a tooltip to indicate that left-clicking the corresponding GUI element will make the camera follow the selected unit.
+	return translate("Left-click to follow.");
+}
+
+function getTemplateViewerOnRightClickTooltip()
+{
+	// Translation: Appears in a tooltip to indicate that right-clicking the corresponding GUI element will open the Template Details GUI page.
+	return translate("Right-click for more information.");
+}
+
+function getTemplateViewerOnClickTooltip()
 {
 	// Translation: Appears in a tooltip to indicate that clicking the corresponding GUI element will open the Template Details GUI page.
-	return translate("Click to view more information.");
+	return translate("Click for more information.");
 }
 
 /**
