@@ -337,25 +337,6 @@ Foundation.prototype.Build = function(builderEnt, work)
 
 		let building = ChangeEntityTemplate(this.entity, this.finalTemplateName);
 
-		// Make sure the foundation object is the same as the final object.
-		const cmpVisual = Engine.QueryInterface(this.entity, IID_Visual);
-		const cmpBuildingVisual = Engine.QueryInterface(building, IID_Visual);
-		if (cmpVisual && cmpBuildingVisual)
-			cmpBuildingVisual.SetActorSeed(cmpVisual.GetActorSeed());
-
-		const cmpIdentity = Engine.QueryInterface(this.entity, IID_Identity);
-		const cmpBuildingIdentity = Engine.QueryInterface(building, IID_Identity);
-		if (cmpIdentity && cmpBuildingIdentity)
-		{
-			const oldPhenotype = cmpIdentity.GetPhenotype();
-			if (cmpBuildingIdentity.GetPhenotype() !== oldPhenotype)
-			{
-				cmpBuildingIdentity.SetPhenotype(oldPhenotype);
-				if (cmpVisualCorpse)
-					cmpVisualCorpse.RecomputeActorName();
-			}
-		}
-
 		if (cmpPlayerStatisticsTracker)
 			cmpPlayerStatisticsTracker.IncreaseConstructedBuildingsCounter(building);
 
