@@ -6,6 +6,13 @@ Engine.RegisterInterface("UnitAI");
  */
 Engine.RegisterMessageType("UnitIdleChanged");
 
+/**
+ * Message of the form { "ableToMove": boolean }
+ * sent from UnitAI whenever the unit's ability to move changes.
+ */
+Engine.RegisterMessageType("UnitAbleToMoveChanged");
+
+
 /**
  * Message of the form { "to": string }
  * where "to" value is a UnitAI stance,
