@@ -5,6 +5,9 @@ PlayerSettingControls.AIConfigButton = class AIConfigButton extends GameSettingC
 		super(...args);
 
 		this.aiConfigButton = Engine.GetGUIObjectByName("aiConfigButton[" + this.playerIndex + "]");
+		this.aiConfigButton.onPress = () => {
+			this.setupWindow.pages.AIConfigPage.openPage(this.playerIndex, this.enabled);
+		};
 
 		g_GameSettings.playerAI.watch(() => this.render(), ["values"]);
 		// Save little performance by not reallocating every call
@@ -12,12 +15,6 @@ PlayerSettingControls.AIConfigButton = class AIConfigButton extends GameSettingC
 		this.render();
 	}
 
-	onLoad()
-	{
-		let aiConfigPage = this.setupWindow.pages.AIConfigPage;
-		this.aiConfigButton.onPress = aiConfigPage.openPage.bind(aiConfigPage, this.playerIndex);
-	}
-
 	render()
 	{
 		this.aiConfigButton.hidden = !g_GameSettings.playerAI.get(this.playerIndex);
